# Hub Pip Plugin

This is currently in development.  Check back soon for an official release.

## Build

[![Build Status](https://travis-ci.org/blackducksoftware/hub-python-plugin.svg?branch=master)](https://travis-ci.org/blackducksoftware/hub-pip)
